RenderCommand

Enum RenderCommand 

pub enum RenderCommand {
    FillPath {
        path: Path,
        rule: FillRule,
        paint: Paint,
        alpha: f32,
    },
    StrokePath {
        path: Path,
        style: StrokeStyle,
        paint: Paint,
        alpha: f32,
    },
    DrawGlyphRun(GlyphRun),
    DrawImage(ImageDraw),
    PushClip {
        path: Path,
        rule: FillRule,
    },
    PushClipStroke {
        path: Path,
        style: StrokeStyle,
    },
    PopClip,
    PushBlendGroup {
        blend_mode: BlendMode,
        isolated: bool,
        knockout: bool,
        bounds: Rect,
        alpha: f32,
        mask: Option<SoftMask>,
    },
    PopBlendGroup,
}

Variants



FillPath

Fields

path: Path
paint: Paint
alpha: f32


StrokePath

Fields

path: Path
paint: Paint
alpha: f32


DrawGlyphRun(GlyphRun)



DrawImage(ImageDraw)



PushClip

Fields

path: Path


PushClipStroke

Intersect the clip with a stroked path’s outline (not its fill). Used to clip a pattern/shading paint to a stroke, since stroke geometry is the backend’s job. Released by the matching RenderCommand::PopClip.

Fields

path: Path


PopClip



PushBlendGroup

Fields

blend_mode: BlendMode
isolated: bool
knockout: bool
bounds: Rect
alpha: f32

Group constant alpha applied when compositing onto the backdrop (the ExtGState /ca in effect when a transparency group is painted).

mask: Option<SoftMask>

ExtGState /SMask soft mask modulating the group composite.



PopBlendGroup